@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# Copyright (c) 2010-2015 Sullivan Beck.  All rights reserved.
+# Copyright (c) 2010-2016 Sullivan Beck.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -31,6 +31,8 @@ $Data{'currency'}{'iso'}{'orig'}{'name'} = {
                            => "Lao People's Democratic Republic",
    "R?UNION"            => "Reunion",
    "SAINT BARTH?LEMY"   => "Saint Barthelemy",
+   "Bolívar"            => "Bolivar",
+   "Bol\x{ed}var"       => "Bolivar",
 };
 
 $Data{'currency'}{'iso'}{'ignore'} = {
@@ -52,5 +54,5 @@ $Data{'currency'}{'iso'}{'ignore'} = {
 # cperl-continued-brace-offset: 0
 # cperl-brace-offset: 0
 # cperl-brace-imaginary-offset: 0
-# cperl-label-offset: -2
+# cperl-label-offset: 0
 # End:
